@@ -984,6 +984,10 @@ failed to upload.</source>
         <source>The storage quota has been used up</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>The uploaded file exceeds the size limit</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>FileTableModel</name>
@@ -1569,6 +1573,14 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Folder for library %1 is removed or moved. The library is unsynced.</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>The file path %1 contains symbols that are not supported by the Windows system.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library is too large to sync.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>PrivateShareDialog</name>
@@ -2183,6 +2195,14 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>failed to open sync error id database</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>The file path contains symbols that are not supported by the Windows system</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Library is too large to sync.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ReliablePostFileTask</name>
@@ -2958,6 +2978,10 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <source>Cancel</source>
         <translation>ביטול</translation>
     </message>
+    <message>
+        <source>Hide Windows incompatibility paths Message</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SharedItemDelegate</name>
@@ -3028,15 +3052,19 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>OK</source>
+        <source>Password(At least 8 characters)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Upload Link</source>
+        <source>Show password</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Upload link:</source>
+        <source>Expire days</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Generate link</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -3220,4 +3248,23 @@ File path contains invalid characters. It is not synced to this computer.</sourc
         <translation>לא</translation>
     </message>
 </context>
+<context>
+    <name>UploadLinkDialog</name>
+    <message>
+        <source>Upload Link</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Upload link:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Copy to clipboard</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 </TS>
\ No newline at end of file
