@@ -779,8 +779,13 @@ void PostFilesTask::onPostTaskFinished(bool success)
         QString file_name = QFileInfo(file_path).fileName();
         failed_path_ = file_name;
 
-        emit oneFileFailed(failed_path_, false);
+        if (http_error_code_ != 442) {
+            emit oneFileFailed(failed_path_, false);
+        } else {
+            emit finished(false);
+        }
         return;
+
     } else {
         error_ = FileNetworkTask::NoError;
         error_string_ = "";
@@ -865,5 +870,7 @@ void FileServerTask::setHttpError(int code)
         // multipart upload request.
         // See https://github.com/haiwen/seafile-server/blob/v6.0.7-server/server/http-status-codes.h#L10
         error_string_ = tr("The storage quota has been used up");
+    } else if (code == 442 ) {
+        error_string_ = tr("The uploaded file exceeds the size limit");
     }
 }
