@@ -1,4 +1,6 @@
+#if !defined(_MSC_VER)
 #include <unistd.h>
+#endif
 #include <algorithm>
 
 #include <sqlite3.h>
