@@ -4,8 +4,13 @@ extern "C" {
 #include <searpc-named-pipe-transport.h>
 
 #include <searpc.h>
+#if defined(_MSC_VER)
+#include <include/seafile.h>
+#include <lib/seafile-object.h>
+#else
 #include <seafile/seafile.h>
 #include <seafile/seafile-object.h>
+#endif
 
 }
 
@@ -27,7 +32,11 @@ extern "C" {
 #endif
 
 #include "rpc-client.h"
+#if defined(_MSC_VER)
+#include <include/seafile-error.h>
+#else
 #include <seafile/seafile-error.h>
+#endif
 
 namespace {
 
@@ -711,16 +720,14 @@ QString SeafileRpcClient::getCcnetPeerId()
 }
 
 int SeafileRpcClient::updateReposServerHost(const QUrl& old_server_url,
-                                            const QString& new_host,
                                             const QString& new_server_url,
                                             QString *err)
 {
     GError *error = NULL;
     int ret =  searpc_client_call__int (seafile_rpc_client_,
                                         "seafile_update_repos_server_host",
-                                        &error, 3,
+                                        &error, 2,
                                         "string", toCStr(old_server_url.toString()),
-                                        "string", toCStr(new_host),
                                         "string", toCStr(new_server_url));
 
     if (ret < 0) {
@@ -889,7 +896,7 @@ int SeafileRpcClient::generateMagicAndRandomKey(int enc_version,
     char *c_magic = NULL;
     char *c_random_key = NULL;
     char *c_salt = NULL;
-    if (enc_version == 3) {
+    if (enc_version == 3 || enc_version == 4) {
         g_object_get (obj,
                     "magic", &c_magic,
                     "random_key", &c_random_key,
@@ -1011,7 +1018,7 @@ bool SeafileRpcClient::getSyncNotification(json_t **ret_obj)
 bool SeafileRpcClient::deleteFileAsyncErrorById(int id)
 {
     GError *error = NULL;
-    int ret = searpc_client_call__int (
+    searpc_client_call__int (
             seafile_rpc_client_,
             "seafile_del_file_sync_error_by_id",
             &error, 1,
