@@ -44,6 +44,10 @@ const char *kFinderSync = "finderSync";
 const char *kLastShibUrl = "lastShiburl";
 #endif // HAVE_SHIBBOLETH_SUPPORT
 
+#if defined(Q_OS_LINUX) || defined(Q_OS_MAC)
+const char * kSetHideWindowsIncompatibilityPathMsg = "setHideWindowsIncompatibilityPathMsg";
+#endif
+
 const char *kUseProxy = "use_proxy";
 const char *kUseSystemProxy = "use_system_proxy";
 const char *kProxyType = "proxy_type";
@@ -51,6 +55,7 @@ const char *kProxyAddr = "proxy_addr";
 const char *kProxyPort = "proxy_port";
 const char *kProxyUsername = "proxy_username";
 const char *kProxyPassword = "proxy_password";
+const char *kHideWindowsIncompatiblePathNotification = "hide_windows_incompatible_path_notification";
 
 const int kCheckSystemProxyIntervalMSecs = 5 * 1000;
 
@@ -649,6 +654,22 @@ void SettingsManager::setFinderSyncExtension(bool enabled)
 }
 #endif // HAVE_FINDER_SYNC_SUPPORT
 
+#if defined(Q_OS_LINUX) || defined(Q_OS_MAC)
+bool SettingsManager::getHideWindowsIncompatibilityPathMsg()
+{
+    QString str;
+    seafApplet->rpcClient()->seafileGetConfig(kHideWindowsIncompatiblePathNotification, &str);
+    return str == "true";
+}
+
+void SettingsManager::setHideWindowsIncompatibilityPathMsg(bool enabled)
+{
+    QString set_value = enabled == true ? "true" : "false";
+    seafApplet->rpcClient()->seafileSetConfig(kHideWindowsIncompatiblePathNotification, set_value);
+    return;
+}
+#endif
+
 #ifdef Q_OS_WIN32
 void SettingsManager::setShellExtensionEnabled(bool enabled)
 {
