@@ -23,6 +23,10 @@
 
 #include "shib-login-dialog.h"
 
+#if defined(_MSC_VER)
+#include <ciso646>
+#endif
+
 namespace {
 
 const char *kSeahubShibCookieName = "seahub_auth";
