@@ -31,8 +31,13 @@ bool compareRepoByTimestamp(const ServerRepo& a, const ServerRepo& b)
 
 QRegExp makeFilterRegExp(const QString& text)
 {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+    return QRegExp(text.split(" ", Qt::SkipEmptyParts).join(".*"),
+                   Qt::CaseInsensitive);
+#else
     return QRegExp(text.split(" ", QString::SkipEmptyParts).join(".*"),
                    Qt::CaseInsensitive);
+#endif
 }
 
 
