@@ -292,8 +292,13 @@ void SyncErrorsTableModel::updateErrors()
         }
 
         errors_[i] = errors[i];
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
+        QModelIndex start = index(i, 0);
+        QModelIndex stop = index(i, MAX_COLUMN - 1);
+#else
         QModelIndex start = QModelIndex().child(i, 0);
         QModelIndex stop = QModelIndex().child(i, MAX_COLUMN - 1);
+#endif
         emit dataChanged(start, stop);
     }
 }
