@@ -336,7 +336,12 @@ void SeafileTrayIcon::showMessage(const QString &title,
     repo_id_ = repo_id;
     commit_id_ = commit_id;
     previous_commit_id_ = previous_commit_id;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
+    auto current_os_version = QOperatingSystemVersion::current();
+    if (current_os_version < QOperatingSystemVersion(QOperatingSystemVersion::MacOS, 10, 8, 0)) {
+#else
     if (QSysInfo::MacintoshVersion < QSysInfo::MV_MOUNTAINLION) {
+#endif
         // qWarning("using old style notifications");
         QIcon info_icon(":/images/info.png");
         TrayNotificationWidget* trayNotification = new TrayNotificationWidget(info_icon.pixmap(32, 32), title, message);
