@@ -2,6 +2,10 @@
 #define SEAFILE_CLIENT_UTILS_WIN_H_
 #include <QtGlobal>
 
+#ifdef Q_OS_WIN32
+#include <windows.h>
+#endif
+
 #ifdef Q_OS_WIN32
 namespace utils {
 namespace win {
@@ -31,6 +35,7 @@ bool isWindows8Point1OrGreater();
 bool isWindows10OrHigher();
 bool fixQtHDPINonIntegerScaling();
 std::string getLocalPipeName(const char *pipeName);
+DWORD runShellAsAdministrator(LPCSTR cmd, LPCSTR arg, int n_show);
 } // namespace win
 } // namespace utils
 #endif
