@@ -1,19 +1,27 @@
 #include <cassert>
 #include <errno.h>
+#if !defined(_MSC_VER)
 #include <dirent.h>
+#endif
 #include <cstdio>
 #include <cstdlib>
+#if !defined(_MSC_VER)
 #include <unistd.h>
+#endif
 #include <sqlite3.h>
 #include <glib.h>
 #include <cstring>
 #include <QObject>
+#include <QApplication>
+#include <QDesktopWidget>
 #include <QString>
 #include <QSettings>
 #include <QProcess>
 #include <QDesktopServices>
 #include <QHostInfo>
 #include <jansson.h>
+#include <QGuiApplication>
+#include <QScreen>
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #include <QUrlQuery>
 #endif
@@ -862,3 +870,18 @@ bool shouldUseFramelessWindow()
 
     return _shouldUseFramelessWindow > 0;
 }
+
+const QRect getScreenSize(int index) {
+    QRect screen;
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+    if (!QGuiApplication::screens().empty()) {
+        screen = QGuiApplication::screens().at(index)->geometry();
+        return screen;
+    } else {
+        return QRect();
+    }
+#else
+    screen = QApplication::desktop()->screenGeometry();
+    return screen;
+#endif
+}
